[![Build Status](https://travis-ci.org/uw-it-cte/uw-ems-client.svg?branch=master)](https://travis-ci.org/uw-it-cte/uw-ems-client)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-cte/uw-ems-client/badge.svg)](https://coveralls.io/github/uw-it-cte/uw-ems-client)

UW EMS SOAP API Client
===========================

A client for the EMS SOAP API

Installation
------------

**Project directory**

Install uw-ems-client in your project.

    $ cd [project]
    $ pip install UW-EMS-Client

Project settings.py
------------------

**EMS API settings**

    EMS_API_HOST = '<EMS Server URL>'
    EMS_API_USERNAME = '<EMS API user>'
    EMS_API_PASSWORD = '<EMS API password>'
